#
# spec file for package iredis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iredis
Version:        1.13.0
Release:        1.3
Summary:        Terminal client for Redis with auto-completion and syntax highlighting
License:        BSD-3-Clause
URL:            https://iredis.io/
Source:         https://files.pythonhosted.org/packages/source/i/iredis/iredis-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
# SECTION tests
# for killall
BuildRequires:  psmisc
BuildRequires:  python3-Pygments >= 2
BuildRequires:  python3-click >= 7.0
BuildRequires:  python3-configobj >= 5.0
BuildRequires:  python3-importlib-resources >= 5.1.0
BuildRequires:  python3-mistune >= 2.0
BuildRequires:  python3-pendulum >= 2.0
BuildRequires:  python3-pexpect
BuildRequires:  python3-pip
BuildRequires:  python3-prompt_toolkit >= 3
BuildRequires:  python3-pytest
BuildRequires:  python3-redis >= 3
BuildRequires:  python3-wcwidth >= 0.1.9
BuildRequires:  python3-wheel
BuildRequires:  redis
# /SECTION
Requires:       python3-Pygments >= 2
Requires:       python3-click >= 7.0
Requires:       python3-configobj >= 5.0
Requires:       python3-importlib-resources >= 5.1.0
Requires:       python3-mistune >= 2.0
Requires:       python3-pendulum >= 2.0
Requires:       python3-prompt_toolkit >= 3
Requires:       python3-redis >= 3
Requires:       python3-wcwidth >= 0.1.9
Recommends:     redis
BuildArch:      noarch

%description
A terminal client for redis with auto-completion and syntax
highlighting. IRedis lets one type Redis commands, and it displays results.

IRedis is an alternative for redis-cli. In most cases, IRedis behaves
exactly the same as redis-cli. IRedis will prevent accidentally
running dangerous commands.

%prep
%setup -q -n iredis-%{version}
# remove the <= version limitations
sed -E -i 's/,<[0-9.]+//' setup.py
# replace == version limitations with >=
sed -E -i 's/==/>=/' setup.py

%build
%python3_build

%install
%python3_install
rm -r %{buildroot}%{python3_sitelib}/tests/
%python_expand %fdupes %{buildroot}%{python3_sitelib}

%check
# increase the timeouts
sed -i 's/timeout=1/timeout=5/' tests/cli_tests/test_*.py
sed -i 's/timeout=2/timeout=5/' tests/cli_tests/test_*.py
sed -i 's/timeout=10/timeout=20/' tests/cli_tests/test_*.py
# the tests are extremely flaky on i586 (hitting timeouts)long as x86_64 succeeds, we don't care as this is noarch
%ifnarch %ix86
%{_sbindir}/redis-server --port 6379 &
# skip test_abort_reading_connection as it fails frequently (timeout) on OBS for no apparent reason, others are bugs upstream: https://github.com/laixintao/iredis/issues/417
# skip test_peek_zset_fetch_all, test_peek_zset_fetch_part, reported upstream: https://github.com/laixintao/iredis/issues/432
# skip test_auto_select_db_and_auth_for_reconnect_only_6 needs further inspection
REDIS_VERSION=$(%{_sbindir}/redis-server --version | grep -o '[0-9]' | head -n 1) PATH=${PATH:+$PATH:}%{buildroot}%{_bindir} PYTHONPATH=${PYTHONPATH:+$PYTHONPATH:}%{buildroot}%{python3_sitelib} PYTHONDONTWRITEBYTECODE=1 pytest --ignore=_build.python3 -vv -k 'not (test_abort_reading_connection or test_peek_set_fetch_part or test_peek_stream or test_timestamp_completer_humanize_time_completion or test_peek_zset_fetch_all or test_peek_zset_fetch_part or test_auto_select_db_and_auth_for_reconnect_only_6)'
killall redis-server
%endif

%files
%{python3_sitelib}/iredis*
%{_bindir}/iredis
%license LICENSE

%changelog
* Mon Jan  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.13:
  * Drop Python 3.6 support
- includes changes from 1.12.2:
  * honor ssl_cert_reqs strategy via --verify-ssl or a rediss://
    URL parameter ssl_cert_reqs
* Wed Aug 31 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.12.1:
  - support HRANDFIELD. by @laixintao in #431
  - add testing on redis 7. by @laixintao in #433
  - bugfix: fix error when pop multiple elements by @Mr3h1v in #436
  - Allow to provide a custom prompt via --prompt by @aymericbeaumet in #437
  - support username for client connection by @laixintao in #438
  - support client_addr and client_id in prompt string, add some tests. by @laixintao in #440
  - support prompt in iredisrc config file by @laixintao in #441
* Wed Jun 29 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable some failing tests (reported upstream) to fix the build.
* Wed Jun 29 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.12:
  - Feature: CLIENT KILL now support LADDR argument.
  - Feature: CLIENT LIST now support ID argument.
  - Feature: CLIENT PAUSE support options and added CLIENT UNPAUSE command.
  - Feature: CLIENT TRACKING support multiple prefixes.
  - Feature: support new command: CLIENT TRACKINGINFO.
  - Feature: support new command: COPY.
  - Feature: support new command: EVAL_RO and EVALSHA_RO.
  - Feature: support new command: EXPIRETIME.
  - Feature: support new command: FAILOVER.
  - Feature: support new command: GEOSEARCH.
  - Feature: support new command: GEOSEARCHRESTORE.
  - Feature: support new command: GETDEL.
  - Feature: support new command: GETEX.
  - Feature: FLUSHDB and FLUSHALL supports SYNC option.
  - Feature: GEOADD supports CH XX NX options.
  - Feature: Timestamp Completers are now support completion for timestamp fields and milliseconds timestamp fields.
  - Deprecate: GEORADIUS is deprecated, no auto-complete for this command anymore.
  - Deprecate: GEORADIUSBYMEMBER is deprecated, no auto-complete for this command anymore.
- update to version 1.11.1:
  - Bugfix: Switch distutils.version to packaging.version to fix the version parse for windows. (new dependency: pypi's python-packaging.
* Fri Jan 28 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Skip a few failings tests (bugs upstream).
* Tue Jan 25 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.11.0:
  - Introduce codespell to find typos by @tssujt in #411
  - upgrade mistune to ^2.0 by @laixintao in #416
* Mon Jan 10 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.10.0:
  - Feature: more human readable output for HELP command like ACL HELP and MEMORY HELP.
  - Feature: you can use Ctrl + C to cancel a blocking command like BLPOP.
  - Test: IRedis now tested under ubuntu-latest (before is ubuntu-16.04)
  - Dependency: Support Python 3.10 now, thanks to tssujt.
* Mon Nov 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Sun Nov 21 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 1.9.4.
